---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

<!-- Give a title explaining the bug/issue -->
#### Bug description
<!-- Describe the issue that you are having -->

#### Expected result
<!-- What should be the expected result? -->

#### Actual result
<!-- What is the result now? -->

#### Steps to reproduce
<!-- If applicable -->

1.
2.
3.
#### Context
<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->

#### Your Environment
<!--- Include as many relevant details about the environment you experienced the bug in -->

* Version used:
* Operating System and version:
* Link to your fork:
